==> xplr-0.17.4.tar.gz: xplr-0.17.4/README.md <==
<h1 align="center">
  ▸[<a href="https://github.com/sayanarijit/xplr/blob/main/assets/icon/xplr.svg"><img src="https://s3.gifyu.com/images/xplr32.png" alt="▓▓" height="20" width="20" /></a> xplr]
</h1>

<p align="center">
A hackable, minimal, fast TUI file explorer
</p>

<p align="center">

<a href="https://crates.io/crates/xplr">
<img src="https://img.shields.io/crates/v/xplr.svg" />
</a>

<a href="https://github.com/sayanarijit/xplr/commits">
<img src="https://img.shields.io/github/commit-activity/m/sayanarijit/xplr" />
</a>

<a href="https://matrix.to/#/#xplr-pub:matrix.org">
<img alt="Matrix" src="https://img.shields.io/matrix/xplr-pub:matrix.org?color=0DB787&label=matrix&logo=Matrix">
</a>
  
<a href="https://discord.gg/JmasSPCcz3">
<img src="https://img.shields.io/discord/834369918312382485?color=5865F2&label=discord&logo=Discord" />
</a>

</p>

<p align="center">
<img src="https://s3.gifyu.com/images/xplr-0.5.0.gif" />
</p>

<h3 align="center">
  [<a href="https://xplr.dev/en/install">Install</a>]
  [<a href="https://xplr.dev/en">Documentation</a>]
  [<a href="https://xplr.dev/en/awesome-hacks">Hacks</a>]
  [<a href="https://xplr.dev/en/awesome-plugins">Plugins</a>]
  [<a href="https://xplr.dev/en/awesome-integrations">Integrations</a>]
  [<a href="https://xplr.dev/en/community">Community</a>]
</h3>

xplr is a terminal UI based file explorer that aims to increase our terminal
productivity by being a flexible, interactive orchestrator for the ever growing
awesome command-line utilities that work with the file-system.

To achieve its goal, xplr strives to be a fast, minimal and more importantly,
hackable file explorer.

xplr is not meant to be a replacement for the standard shell commands or the
GUI file managers. Rather, it aims to [integrate them all][14] and expose an
intuitive, scriptable, [keyboard controlled][2],
[real-time visual interface][1], also being an ideal candidate for [further
integration][15], enabling you to achieve insane terminal productivity.

## Introductions & Reviews

- [[VIDEO] XPLR: Insanely Hackable Lua File Manager ~ Brodie Robertson](https://youtu.be/MaVRtYh1IRU)

## Packaging

<a href="https://repology.org/project/xplr/versions"><img src="https://repology.org/badge/vertical-allrepos/xplr.svg" /></a>

## Backers

<a href="https://opencollective.com/xplr#backer"><img src="https://opencollective.com/xplr/tiers/backer.svg?width=890" /></a>

[1]: https://xplr.dev/en/layouts
[2]: https://xplr.dev/en/configure-key-bindings
[14]: https://xplr.dev/en/awesome-plugins#integration
[15]: https://xplr.dev/en/awesome-integrations

==> xplr-0.19.3.tar.gz: xplr-0.19.3/README.md <==
<h1 align="center">
  ▸[<a href="https://github.com/sayanarijit/xplr/blob/main/assets/icon/xplr.svg"><img src="https://s3.gifyu.com/images/xplr32.png" alt="▓▓" height="20" width="20" /></a> xplr]
</h1>

<p align="center">
A hackable, minimal, fast TUI file explorer
</p>

<p align="center">

<a href="https://crates.io/crates/xplr">
<img src="https://img.shields.io/crates/v/xplr.svg" />
</a>

<a href="https://github.com/sayanarijit/xplr/commits">
<img src="https://img.shields.io/github/commit-activity/m/sayanarijit/xplr" />
</a>

<a href="https://matrix.to/#/#xplr-pub:matrix.org">
<img alt="Matrix" src="https://img.shields.io/matrix/xplr-pub:matrix.org?color=0DB787&label=matrix&logo=Matrix">
</a>
  
<a href="https://discord.gg/JmasSPCcz3">
<img src="https://img.shields.io/discord/834369918312382485?color=5865F2&label=discord&logo=Discord" />
</a>

</p>

<p align="center">

https://user-images.githubusercontent.com/11632726/166747867-8a4573f2-cb2f-43a6-a23d-c99fc30c6594.mp4

</p>

<h3 align="center">
  [<a href="https://xplr.dev/en/install">Install</a>]
  [<a href="https://xplr.dev/en">Documentation</a>]
  [<a href="https://xplr.dev/en/awesome-hacks">Hacks</a>]
  [<a href="https://xplr.dev/en/awesome-plugins">Plugins</a>]
  [<a href="https://xplr.dev/en/awesome-integrations">Integrations</a>]
  [<a href="https://xplr.dev/en/community">Community</a>]
</h3>

xplr is a terminal UI based file explorer that aims to increase our terminal
productivity by being a flexible, interactive orchestrator for the ever growing
awesome command-line utilities that work with the file-system.

To achieve its goal, xplr strives to be a fast, minimal and more importantly,
hackable file explorer.

xplr is not meant to be a replacement for the standard shell commands or the
GUI file managers. Rather, it aims to [integrate them all][14] and expose an
intuitive, scriptable, [keyboard controlled][2],
[real-time visual interface][1], also being an ideal candidate for [further
integration][15], enabling you to achieve insane terminal productivity.

## Introductions & Reviews

- [[VIDEO] XPLR: Insanely Hackable Lua File Manager ~ Brodie Robertson](https://youtu.be/MaVRtYh1IRU)

## Packaging

<a href="https://repology.org/project/xplr/versions"><img src="https://repology.org/badge/vertical-allrepos/xplr.svg" /></a>

## Backers

<a href="https://opencollective.com/xplr#backer"><img src="https://opencollective.com/xplr/tiers/backer.svg?width=890" /></a>

[1]: https://xplr.dev/en/layouts
[2]: https://xplr.dev/en/configure-key-bindings
[14]: https://xplr.dev/en/awesome-plugins#integration
[15]: https://xplr.dev/en/awesome-integrations
